// cCDCdatabase.cpp: implementation of the cCDCdatabase class.
//
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "ViewDeepSky.h"
#include "cCDCdatabase.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

cCDCdatabase::cCDCdatabase(CString dllpath, HANDLE app)
{
	// Load the dll.
	hDLL = ::LoadLibrary(dllpath);

    // Get adress for all functions from the ddl.

	// Init functions.
    InitCat        = (INITCAT)        ::GetProcAddress(hDLL, "InitCat");
    SetCatLang     = (SETCATLANG)     ::GetProcAddress(hDLL, "SetCatLang");
    InitCatWin     = (INITCATWIN)     ::GetProcAddress(hDLL, "InitCatWin");

    // Yale BSC
    OpenBSC        = (OPENBSC)        ::GetProcAddress(hDLL, "OpenBSC");
    OpenBSCwin     = (OPENBSCWIN)     ::GetProcAddress(hDLL, "OpenBSCwin");
    ReadBSC        = (READBSC)        ::GetProcAddress(hDLL, "ReadBSC");
    NextBSC        = (NEXTBSC)        ::GetProcAddress(hDLL, "NextBSC");
    CloseBSC       = (CLOSEBSC)       ::GetProcAddress(hDLL, "CloseBSC");

    // Sky2000 Master Catalog
    SetSKYpath     = (SETSKYPATH)     ::GetProcAddress(hDLL, "SetSKYpath");
    OpenSKY        = (OPENSKY)        ::GetProcAddress(hDLL, "OpenSKY");
    OpenSKYwin     = (OPENSKYWIN)     ::GetProcAddress(hDLL, "OpenSKYwin");
    ReadSKY        = (READSKY)        ::GetProcAddress(hDLL, "ReadSKY");
    NextSKY        = (NEXTSKY)        ::GetProcAddress(hDLL, "NextSKY");
    CloseSKY       = (CLOSESKY)       ::GetProcAddress(hDLL, "CloseSKY");

    // Tycho catalog
    SetTYCpath     = (SETTYCPATH)     ::GetProcAddress(hDLL, "SetTYCpath");
    OpenTYC        = (OPENTYC)        ::GetProcAddress(hDLL, "OpenTYC");
    OpenTYCwin     = (OPENTYCWIN)     ::GetProcAddress(hDLL, "OpenTYCwin");
    ReadTYC        = (READTYC)        ::GetProcAddress(hDLL, "ReadTYC");
    NextTYC        = (NEXTTYC)        ::GetProcAddress(hDLL, "NextTYC");
    CloseTYC       = (CLOSETYC)       ::GetProcAddress(hDLL, "CloseTYC");

    // Tycho-2 catalog
    SetTY2path     = (SETTY2PATH)     ::GetProcAddress(hDLL, "SetTY2path");
    OpenTY2        = (OPENTY2)        ::GetProcAddress(hDLL, "OpenTY2");
    OpenTY2win     = (OPENTY2WIN)     ::GetProcAddress(hDLL, "OpenTY2win");
    ReadTY2        = (READTY2)        ::GetProcAddress(hDLL, "ReadTY2");
    NextTY2        = (NEXTTY2)        ::GetProcAddress(hDLL, "NextTY2");
    CloseTY2       = (CLOSETY2)       ::GetProcAddress(hDLL, "CloseTY2");

    // Tycho Input catalog
    SetTICpath     = (SETTICPATH)     ::GetProcAddress(hDLL, "SetTICpath");
    OpenTIC        = (OPENTIC)        ::GetProcAddress(hDLL, "OpenTIC");
    OpenTICwin     = (OPENTICWIN)     ::GetProcAddress(hDLL, "OpenTICwin");
    ReadTIC        = (READTIC)        ::GetProcAddress(hDLL, "ReadTIC");
    NextTIC        = (NEXTTIC)        ::GetProcAddress(hDLL, "NextTIC");
    CloseTIC       = (CLOSETIC)       ::GetProcAddress(hDLL, "CloseTIC");

    // Guide Star catalog (version produite par convgsc.exe)  XXX
    SetGSCpath     = (SETGSCPATH)     ::GetProcAddress(hDLL, "SetGSCpath");
    OpenGSC        = (OPENGSC)        ::GetProcAddress(hDLL, "OpenGSC");
    OpenGSCwin     = (OPENGSCWIN)     ::GetProcAddress(hDLL, "OpenGSCwin");
    ReadGSC        = (READGSC)        ::GetProcAddress(hDLL, "ReadGSC");
    NextGSC        = (NEXTGSC)        ::GetProcAddress(hDLL, "NextGSC");
    CloseGSC       = (CLOSEGSC)       ::GetProcAddress(hDLL, "CloseGSC");

    // Guide Star catalog (Original version FITS)
    SetGSCFpath    = (SETGSCFPATH)    ::GetProcAddress(hDLL, "SetGSCFpath");
    OpenGSCF       = (OPENGSCF)       ::GetProcAddress(hDLL, "OpenGSCF");
    OpenGSCFwin    = (OPENGSCFWIN)    ::GetProcAddress(hDLL, "OpenGSCFwin");
    ReadGSCF       = (READGSCF)       ::GetProcAddress(hDLL, "ReadGSCF");
    CloseGSCF      = (CLOSEGSCF)      ::GetProcAddress(hDLL, "CloseGSCF");

    // Guide Star catalog (Compact version of CDS)
    SetGSCCpath    = (SETGSCCPATH)    ::GetProcAddress(hDLL, "SetGSCCpath");
    OpenGSCC       = (OPENGSCC)       ::GetProcAddress(hDLL, "OpenGSCC");
    OpenGSCCwin    = (OPENGSCCWIN)    ::GetProcAddress(hDLL, "OpenGSCCwin");
    ReadGSCC       = (READGSCC)       ::GetProcAddress(hDLL, "ReadGSCC");
    NextGSCC       = (NEXTGSCC)       ::GetProcAddress(hDLL, "NextGSCC");
    CloseGSCC      = (CLOSEGSCC)      ::GetProcAddress(hDLL, "CloseGSCC");

    // MicroCat
    SetMCTpath     = (SETMCTPATH)     ::GetProcAddress(hDLL, "SetMCTpath");
    OpenMCTwin     = (OPENMCTWIN)     ::GetProcAddress(hDLL, "OpenMCTwin");
    OpenMCT        = (OPENMCT)        ::GetProcAddress(hDLL, "OpenMCT");
    ReadMCT        = (READMCT)        ::GetProcAddress(hDLL, "ReadMCT");
    CloseMCT       = (CLOSEMCT)       ::GetProcAddress(hDLL, "CloseMCT");

    // US Naval Observatory USNO-A1,SA1,A2,SA2 catalog
    SetUSNOApath   = (SETUSNOAPATH)   ::GetProcAddress(hDLL, "SetUSNOApath");
    OpenUSNOAwin   = (OPENUSNOAWIN)   ::GetProcAddress(hDLL, "OpenUSNOAwin");
    OpenUSNOA      = (OPENUSNOA)      ::GetProcAddress(hDLL, "OpenUSNOA");
    ReadUSNOA      = (READUSNOA)      ::GetProcAddress(hDLL, "ReadUSNOA");
    CloseUSNOA     = (CLOSEUSNOA)     ::GetProcAddress(hDLL, "CloseUSNOA");

    // SAGUARO ASTRONOMY CLUB DATABASE  V7
    SetSACpath     = (SETSACPATH)     ::GetProcAddress(hDLL, "SetSACpath");
    OpenSAC        = (OPENSAC)        ::GetProcAddress(hDLL, "OpenSAC");
    OpenSACwin     = (OPENSACWIN)     ::GetProcAddress(hDLL, "OpenSACwin");
    ReadSAC        = (READSAC)        ::GetProcAddress(hDLL, "ReadSAC");
    CloseSAC       = (CLOSESAC)       ::GetProcAddress(hDLL, "CloseSAC");

    // NGC 2000
    SetNGCpath     = (SETNGCPATH)     ::GetProcAddress(hDLL, "SetNGCpath");
    OpenNGC        = (OPENNGC)        ::GetProcAddress(hDLL, "OpenNGC");
    OpenNGCwin     = (OPENNGCWIN)     ::GetProcAddress(hDLL, "OpenNGCwin");
    ReadNGC        = (READNGC)        ::GetProcAddress(hDLL, "ReadNGC");
    CloseNGC       = (CLOSENGC)       ::GetProcAddress(hDLL, "CloseNGC");

    // Lynds' Catalogue of Bright Nebulae
    SetLBNpath     = (SETLBNPATH)     ::GetProcAddress(hDLL, "SetLBNpath");
    OpenLBN        = (OPENLBN)        ::GetProcAddress(hDLL, "OpenLBN");
    OpenLBNwin     = (OPENLBNWIN)     ::GetProcAddress(hDLL, "OpenLBNwin");
    ReadLBN        = (READLBN)        ::GetProcAddress(hDLL, "ReadLBN");
    CloseLBN       = (CLOSELBN)       ::GetProcAddress(hDLL, "CloseLBN");

    // Third Reference Cat. of Bright Galaxies (RC3)
    SetRC3path     = (SETRC3PATH)     ::GetProcAddress(hDLL, "SetRC3path");
    OpenRC3        = (OPENRC3)        ::GetProcAddress(hDLL, "OpenRC3");
    OpenRC3win     = (OPENRC3WIN)     ::GetProcAddress(hDLL, "OpenRC3win");
    ReadRC3        = (READRC3)        ::GetProcAddress(hDLL, "ReadRC3");
    CloseRC3       = (CLOSERC3)       ::GetProcAddress(hDLL, "CloseRC3");

    // Catalogue of Principal Galaxies (PGC)
    SetPGCpath     = (SETPGCPATH)     ::GetProcAddress(hDLL, "SetPGCpath");
    OpenPGC        = (OPENPGC)        ::GetProcAddress(hDLL, "OpenPGC");
    OpenPGCwin     = (OPENPGCWIN)     ::GetProcAddress(hDLL, "OpenPGCwin");
    ReadPGC        = (READPGC)        ::GetProcAddress(hDLL, "ReadPGC");
    ClosePGC       = (CLOSEPGC)       ::GetProcAddress(hDLL, "ClosePGC");

    // Open Cluster Data
    SetOCLpath     = (SETOCLPATH)     ::GetProcAddress(hDLL, "SetOCLpath");
    OpenOCL        = (OPENOCL)        ::GetProcAddress(hDLL, "OpenOCL");
    OpenOCLwin     = (OPENOCLWIN)     ::GetProcAddress(hDLL, "OpenOCLwin");
    ReadOCL        = (READOCL)        ::GetProcAddress(hDLL, "ReadOCL");
    CloseOCL       = (CLOSEOCL)       ::GetProcAddress(hDLL, "CloseOCL");

    // Globular Clusters in the Milky Way
    SetGCMpath     = (SETGCMPATH)     ::GetProcAddress(hDLL, "SetGCMpath");
    OpenGCM        = (OPENGCM)        ::GetProcAddress(hDLL, "OpenGCM");
    OpenGCMwin     = (OPENGCMWIN)     ::GetProcAddress(hDLL, "OpenGCMwin");
    ReadGCM        = (READGCM)        ::GetProcAddress(hDLL, "ReadGCM");
    CloseGCM       = (CLOSEGCM)       ::GetProcAddress(hDLL, "CloseGCM");

    // Strasbourg-ESO Catalogue of Galactic Planetary Nebulae
    SetGPNpath     = (SETGPNPATH)     ::GetProcAddress(hDLL, "SetGPNpath");
    OpenGPN        = (OPENGPN)        ::GetProcAddress(hDLL, "OpenGPN");
    OpenGPNwin     = (OPENGPNWIN)     ::GetProcAddress(hDLL, "OpenGPNwin");
    ReadGPN        = (READGPN)        ::GetProcAddress(hDLL, "ReadGPN");
    CloseGPN       = (CLOSEGPN)       ::GetProcAddress(hDLL, "CloseGPN");

    // Washington Visual Double Star Catalog
    SetWDSpath     = (SETWDSPATH)     ::GetProcAddress(hDLL, "SetWDSpath");
    OpenWDS        = (OPENWDS)        ::GetProcAddress(hDLL, "OpenWDS");
    OpenWDSwin     = (OPENWDSWIN)     ::GetProcAddress(hDLL, "OpenWDSwin");
    ReadWDS        = (READWDS)        ::GetProcAddress(hDLL, "ReadWDS");
    NextWDS        = (NEXTWDS)        ::GetProcAddress(hDLL, "NextWDS");
    CloseWDS       = (CLOSEWDS)       ::GetProcAddress(hDLL, "CloseWDS");

    // General Catalog of Variable Stars (+NSV +EVS)    SetBSCpath     = (SETBSCPATH)     ::GetProcAddress(hDLL, "SetBSCpath");
    SetGCVpath     = (SETGCVPATH)     ::GetProcAddress(hDLL, "SetGCVpath");
    OpenGCV        = (OPENGCV)        ::GetProcAddress(hDLL, "OpenGCV");
    OpenGCVwin     = (OPENGCVWIN)     ::GetProcAddress(hDLL, "OpenGCVwin");
    ReadGCV        = (READGCV)        ::GetProcAddress(hDLL, "ReadGCV");
    NextGCV        = (NEXTGCV)        ::GetProcAddress(hDLL, "NextGCV");
    CloseGCV       = (CLOSEGCV)       ::GetProcAddress(hDLL, "CloseGCV");

    // Recherche de la position d'un objet ( ne pas oublier d'appeller la SetPathXXX corespondante)
    FindNumNGC     = (FINDNUMNGC)     ::GetProcAddress(hDLL, "FindNumNGC");
    FindNumIC      = (FINDNUMIC)      ::GetProcAddress(hDLL, "FindNumIC");
    FindNumMessier = (FINDNUMMESSIER) ::GetProcAddress(hDLL, "FindNumMessier");
    FindNumGCVS    = (FINDNUMGCVS)    ::GetProcAddress(hDLL, "FindNumGCVS");
    FindNumGSC     = (FINDNUMGSC)     ::GetProcAddress(hDLL, "FindNumGSC");
    FindNumGSCF    = (FINDNUMGSCF)    ::GetProcAddress(hDLL, "FindNumGSCF");
    FindNumGSCC    = (FINDNUMGSCC)    ::GetProcAddress(hDLL, "FindNumGSCC");
    FindNumGC      = (FINDNUMGC)      ::GetProcAddress(hDLL, "FindNumGC");
    FindNumHR      = (FINDNUMHR)      ::GetProcAddress(hDLL, "FindNumHR");
    FindNumBayer   = (FINDNUMBAYER)   ::GetProcAddress(hDLL, "FindNumBayer");
    FindNumFlam    = (FINDNUMFLAM)    ::GetProcAddress(hDLL, "FindNumFlam");
    FindNumHD      = (FINDNUMHD)      ::GetProcAddress(hDLL, "FindNumHD");
    FindNumSAO     = (FINDNUMSAO)     ::GetProcAddress(hDLL, "FindNumSAO");
    FindNumBD      = (FINDNUMBD)      ::GetProcAddress(hDLL, "FindNumBD");
    FindNumCD      = (FINDNUMCD)      ::GetProcAddress(hDLL, "FindNumCD");
    FindNumCPD     = (FINDNUMCPD)     ::GetProcAddress(hDLL, "FindNumCPD");
    FindNumPGC     = (FINDNUMPGC)     ::GetProcAddress(hDLL, "FindNumPGC");
    FindNumSAC     = (FINDNUMSAC)     ::GetProcAddress(hDLL, "FindNumSAC");

    // Now start to use some of the functions.

	// Call the init functions.
    InitCat(app, true);

	shortstring a, b, c, d;
	a.Set("Give the correct path for");
	b.Set("Mount disk for");
	c.Set("Configuration error for");
	d.Set("My application caption");
	SetCatLang(a.GetSS(), b.GetSS(), c.GetSS(), d.GetSS());
}

cCDCdatabase::~cCDCdatabase()
{
    // Get rid of the dll handle.
	FreeLibrary(hDLL);
}


