// cCDCdatabase.h: interface for the cCDCdatabase class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_CCDCDATABASE_H__7A95BE14_EB96_499E_AEB3_4E70F9247974__INCLUDED_)
#define AFX_CCDCDATABASE_H__7A95BE14_EB96_499E_AEB3_4E70F9247974__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

///////////////////////////////////////////////////////////////////////////////
// shortstring is used in some of the Pascal functions supplied in the CDC dll.
// shortstring is not supported in C++ so this class acts as an interface to
// this Pascal type.
struct shortstring  
{
    // shortstring is 0 to 255 in length, the first byte is the length string[0]
    // the remaining bytes are the string, string[1] to string[255].
	char string[256];

	void Set(char *str)
	{
		strcpy(&string[1], str);
		string[0] = (unsigned char)strlen(str);
	}

	void Set(CString str)
	{
		strcpy(&string[1], str); // place the string in the 2nd char onwards.
		string[0] = (unsigned char)strlen(str); // store length in the 1st char.
	}

	char *Get()
	{
		return &string[1]; // return everything past the 1st char as a char*
	}

	char *GetSS()
	{
		return string; // return everything including the 1st char as a char*
	}
};

///////////////////////////////////////////////////////////////////////////////
// All of the CDC data types.

// Yale BSC
typedef struct
{
	long hd,            // HD catalog number
		 bs,            // bright star catalog number
		 ar,            // ra J2000 in degrees * 100,000
		 de;            // Declination J2000 * 100,000
	short pmar,         // Proper motion in ra in milli-arcseconds
		  pmde;         // Proper motion in dec in milli-arcseconds
	short mv,           // Visual magnitude * 100
		  b_v;          // Colour index B-V * 100
	char cons[3];       // Constellation
	byte flam;          // Flamsteed number
	char bayer[4];      // Bayer letter
	char sp[20];        // Spectral class
} BSCrec;

// Sky2000 Master Catalog
typedef struct
{
	long ar,            // ra J2000 in degrees * 100,000
		 de;            // Declination J2000 * 100,000
	short mv,           // Visual magnitude * 100
		  b_v,          // Colour index B-V * 100
		  d_m,          // Magnitude difference (double) * 100
		  pmar,         // Proper motion in ra in milli-arcseconds
		  pmde;         // Proper motion in dec in milli-arcseconds
	unsigned short sep; // Separation in seconds (double) * 100
	char sp[3];         // Spectral class
	char dm_cat[2];     // Catalogue BD
	long dm;            // BD number
	long hd,            // HD number
		 sao;           // SAO number
} SKYrec;

// Tycho catalog
typedef struct
{
	long ar,            // ra J2000 in degrees * 100,000
		 de;            // Declination J2000 * 100,000
	unsigned short gscz;// GSC region
	unsigned short gscn;// Star number within region GSC   XXX
	unsigned short tycn;// Constituent number.             XXX
	short bt,           // Average magnitude BT * 100      XXX
		  vt,           // Average magnitude VT * 100      XXX
		  b_v,          // Colour index B-V * 100
		  pmar,         // Proper motion in ra in milli-arcseconds
		  pmde;         // Proper motion in dec in milli-arcseconds
} TYCrec;

// Tycho-2 catalog
typedef struct
{
	double ar,          // ra J2000 in degrees * 100,000
		   de;          // Declination J2000 * 100,000
	unsigned short gscz;// GSC region
	unsigned short gscn;// Star number within region GSC   XXX
	unsigned short tycn;// Constituent number.             XXX
	double bt,          // Magnitude BT * 100      XXX
		   vt,          // Magnitude VT * 100      XXX
		   pmar,        // Proper motion in ra in milli-arcseconds
		   pmde;        // Proper motion in dec in milli-arcseconds
} TY2rec;

// Tycho Input catalog
typedef struct
{
	long ar,            // ra J2000 in degrees * 100,000
		 de;            // Declination J2000 * 100,000
	unsigned short gscz;// GSC region
	unsigned short gscn;// Star number within region GSC   XXX
	short mb,           // Magnitude B * 100 + flag16 * 10000   XXX what is flag 16?
		  mv;           // Magnitude V * 100
} TICrec;

// Guide Star catalog (version produite par convgsc.exe)  XXX
typedef struct
{
	long ar,            // ra J2000 in degrees * 100,000
		 de;            // Declination J2000 * 100,000
	unsigned short gscn;// Star number within region GSC   XXX
    short pe,           // Positional error * 10
		  m,            // Magnitude * 100
		  me;           // Magnitude error * 100
    char mb,            // bande passantes de magnitude XXX ???
         cl;            // Object class
    char mult;          // Multiple star
} GSCrec;

// Guide Star catalog (Original version FITS)
typedef struct
{
	double ar,          // ra J2000 in degrees * 100,000
		   de;          // Declination J2000 * 100,000
	long   gscn;        // Star number within region GSC   XXX
    double pe,          // Positional error 
           m,           // Magnitude
           me;          // Magnitude error
    long mb,            // bande passantes de magnitude XXX ???
         cl;            // Object class
    shortstring plate,  // Plate number
                mult;   // Multiple star
} GSCFrec;

// Guide Star catalog (Compact version of CDS)
typedef struct
{
	double ar,          // ra J2000 in degrees * 100,000
		   de;          // Declination J2000 * 100,000
	long   gscn;        // Star number within region GSC   XXX
    double pe,          // Positional error 
           m,           // Magnitude
           me;          // Magnitude error
    long mb,            // bande passantes de magnitude XXX ???
         cl;            // Object class
    shortstring plate,  // Plate number
                mult;   // Multiple star
} GSCCrec;

// US Naval Observatory USNO-A1,SA1,A2,SA2 catalog
typedef struct
{
    shortstring id;     // Star number.
    double ar;          // RA J2000 in hours.
    double de;          // declination J2000
    double mb;          // "Blue" magnitude
    double mr;          // "Red" magnitude
    long field,         // Plate number
         q,             // Photographic quality
         s;             // -1 = figure in the catalogue of calibration (GSC or ACT)
} USNOArec;

// MicroCat
typedef struct
{
    double ar;          // ra J2000 in hours
    double de;          // declination J2000
    double mb;          // "Blue" magnitude
    double mr;          // "Red" magnitude
} MCTrec;

// SAGUARO ASTRONOMY CLUB DATABASE  V7
typedef struct
{
    float ar,           // ra J2000 in degrees
        de,             // declination J2000
        ma,             // Magnitude
        sbr,            // Surface magnitude
        s1,             // Largest dimension in minutes
        s2;             // Smallest dimension in minutes
    byte pa;            // Position angle of largest axis
    char nom1[17];      // Id
    char nom2[18];      // Other Id
    char typ[3];        // Object type
    char cons[3];       // Constellation
    char desc[120];     // Description
    char clas[11];      // Other class
} SACrec;

// NGC 2000
typedef struct
{
	long ar,            // ra J2000 in degrees * 100,000
		 de;            // Declination J2000 * 100,000
	unsigned short id;  // NGC/ID number
	char ic;            // I for IC, blank for NGC
	char typ[3];        // Object type
	char l_dim;         //
	char n_mag;         // photographic magnitude
	short ma,           // magnitude * 100
		  dim;          // largest dimension in minutes * 10
	char cons[3];       // constellation
	char desc[50];      // description
} NGCrec;

// Lynds' Catalogue of Bright Nebulae
typedef struct
{
	long ar,            // ra J2000 in degrees * 100,000
		 de;            // Declination J2000 * 100,000
    float area;         // Surface area of nebulosity in square degrees
    unsigned short num, // Sequence number
                   d1,  // Largest dimension in minutes
                   d2,  // Smallest dimension in minutes
                   id;  // Region id
    byte color,         // Colour index
         bright;        // Luminosity index
    char name[8];       // Name
} LBNrec;

// Third Reference Cat. of Bright Galaxies (RC3)
typedef struct
{
	long ar,            // ra J2000 in degrees * 100,000
		 de,            // Declination J2000 * 100,000
         vgsr;          // Average radial speed
    char pgc[8];        // PGC catalogue number
    char nom[14];       // Other number
    char typ[7];        // Morphological type
    char pa;            // Position angle of largest axis
    short stage,        // Hubble stage * 10
          lumcl,        // Luminosity class * 10
          d25,          // log du grand axes  l'isophote 25/'2 * 100 XXX
          r25,          // log du rapport grand axe / petit axe  * 100 XXX
          Ae,           // log de l'ouverture effective * 100 XXX
          mb,           // Total photographic B magnitude * 100
          b_vt,         // Total colour index B-V * 100
          b_ve,         // indice de couleur b-v dans l'ouverture effective * 100 XXX
          m25,          // Average magnitude per square minute * 100 XXX
          me;           // magnitude / minute carre dans l'ouverture effective * 100 XXX
} RC3rec;

// Catalogue of Principal Galaxies (PGC)
typedef struct
{
    long pgc,           // PGC catalogue number
         ar,            // ra J2000 in degrees * 100,000
         de,            // Declination J2000 * 100,000
         hrv;           // Heliocentric radial velocity
    char nom[16];       // Other number
    char typ[4];        // Morphological type
    char pa;            // Position angle of largest axis
    short maj,          // grand axe  l'isophote 25/'2 * 100 XXX
          min,          // petit axe  l'isophote 25/'2 * 100 XXX
          mb;           // Magnitude B * 100
} PGCrec;

// Open Cluster Data
typedef struct
{
	long ar,            // ra J2000 in degrees * 100,000
		 de;            // Declination J2000 * 100,000
    short cat,          // Catalogue number
          num,          // Sequence number in the catalogue
          ocl,          // OCL number
          dim,          // Dimension in minutes * 100
          dist,         // Distance in parsecs
          age,          // log de l'age de l'amas * 100
          ms,           // Magnitude of brightest star * 100
          mt,           // Total magnitude * 100
          b_v,          // Total colour index B-V * 100
          ns;           // Number of stars
    char conc,          // Trumpler concentration class
         range,         // Trumpler scale
         rich,          // Trumpler richness class
         neb;           // Trumpler nebulosity class
} OCLrec;

// Globular Clusters in the Milky Way
typedef struct
{
	long ar,            // ra J2000 in degrees * 100,000
		 de;            // Declination J2000 * 100,000
    short Rsun,         // Distance from sun in kpc * 10
          Vt,           // Integrated magnitude V * 100
          B_Vt,         // Colour index B-V * 100
          c,            // Central concentration * 100
          Rc,           // Radius of nucleus * 100
          Rh,           // rayon de demi-masse * 100XXX
          muV;          // Core surface luminosity
    char id[9];         // numros de l'amas XXX
    char name[11];      // Other name
    char SpT[4];        // Integrated spectral class
} GCMrec;

// Strasbourg-ESO Catalogue of Galactic Planetary Nebulae
typedef struct
{
	long ar,            // ra J2000 in degrees * 100,000
		 de;            // Declination J2000 * 100,000
    short dim,          // Dimension in arc seconds * 10
          mv,           // Visual magnitude * 100
          mHb,          // HBeta magnitude * 100 (10 + s.5 (-10-FlucHBeta))
          cs_b,         // Magnitude B of central star * 100
          cs_v;         // Magnitude V of central star * 100
    char ldim,          // Limiting dimension
         lv,            // Limiting visual magnitude
         morph,         // Morphological index
         cs_lb,         // Limiting magnitude B of central star * 100
         cs_lv;         // Limiting magnitude V of central star * 100
    char png[10];       // Id planetary nebula
    char pk[9];         // Perek-Kohoutek Id
    char name[13];      // Other name of the planetary nebula
} GPNrec;

// Washington Visual Double Star Catalog
typedef struct
{
	long ar,            // ra J2000 in degrees * 100,000
		 de,            // Declination J2000 * 100,000
         dm;            // Zone and number BD
    short date1,        // Date of first observation
          date2,        // Date of second observation
          pa1,          // Position angle on date1
          pa2,          // Position angle on date2
          sep1,         // Separation in seconds on date1 * 10
          sep2,         // Separation in seconds on date2 * 10
          ma,           // Magnitude of primary star
          mb;           // Magnitude of secondary star
    char id[7];         // Star's id
    char comp[5];       // Id
    char sp[9];         // Spectral class
    char note[2];       // Notes
} WDSrec;

// General Catalog of Variable Stars (+NSV +EVS)
typedef struct
{
	long ar,            // ra J2000 in degrees * 100,000
		 de,            // Declination J2000 * 100,000
         num;           // Star number in constellation XXX
    float period;       // Variable's period in days
    short max,          // Maximum magnitude * 100
          min;          // Minimum magnitude * 100
    char lmax,          // Length of maximum XXX
         lmin,          // Length of minimum XXX
         mcode;         // Photometric system XXX
    char gcvs[10],      // Variable star Id
         vartype[10];   // Variable type + year of nova
} GCVrec;

///////////////////////////////////////////////////////////////////////////////
// Main class to access the CDC catalog.dll.

class cCDCdatabase  
{
private:
	HINSTANCE hDLL; // Used to store a handle to the catalog.dll

public:
	cCDCdatabase(CString dllpath, HANDLE app);
	virtual ~cCDCdatabase();

    // Main setup interface.
    typedef void (FAR PASCAL * INITCAT)(HANDLE hnd, bool cache);
    INITCAT InitCat;
    typedef void (FAR PASCAL * SETCATLANG)(char *msg1, char *msg2, char *msg3, char *capt);
    SETCATLANG SetCatLang;
    typedef void (FAR PASCAL * INITCATWIN)(double ax,double ay,double bx,double by,double st,double ct,double ac,double dc,double azc,double hc,double jdt,double sidt,double lat,
        long pjp,long xs,long ys,long xi,long xa,long yi,long ya, char projt, bool np, bool sp);
    INITCATWIN InitCatWin;

    // Yale BSC
    typedef void (FAR PASCAL * SETBSCPATH)(char *path);
    SETBSCPATH SetBSCpath;
    typedef void (FAR PASCAL * OPENBSC)(double ar1, double ar2, double de1, double de2, bool &ok);
    OPENBSC OpenBSC;
    typedef void (FAR PASCAL * OPENBSCWIN)(bool &ok);
    OPENBSCWIN OpenBSCwin;
    typedef void (FAR PASCAL * READBSC)(BSCrec &lin, bool &ok);
    READBSC ReadBSC;
    typedef void (FAR PASCAL * NEXTBSC)( bool &ok);
    NEXTBSC NextBSC;
    typedef void (FAR PASCAL * CLOSEBSC)();
    CLOSEBSC  CloseBSC ;

    // Sky2000 Master Catalog
    typedef void (FAR PASCAL * SETSKYPATH)(char *path);
    SETSKYPATH SetSKYpath;
    typedef void (FAR PASCAL * OPENSKY)(double ar1, double ar2, double de1, double de2, bool &ok);
    OPENSKY OpenSKY;
    typedef void (FAR PASCAL * OPENSKYWIN)(bool &ok);
    OPENSKYWIN OpenSKYwin;
    typedef void (FAR PASCAL * READSKY)(SKYrec &lin, bool &ok);
    READSKY ReadSKY;
    typedef void (FAR PASCAL * NEXTSKY)( bool &ok);
    NEXTSKY NextSKY;
    typedef void (FAR PASCAL * CLOSESKY)();
    CLOSESKY  CloseSKY ;

    // Tycho catalogue
    typedef void (FAR PASCAL * SETTYCPATH)(char *path);
    SETTYCPATH SetTYCpath;
    typedef void (FAR PASCAL * OPENTYC)(double ar1, double ar2, double de1, double de2, bool &ok);
    OPENTYC OpenTYC;
    typedef void (FAR PASCAL * OPENTYCWIN)(bool &ok);
    OPENTYCWIN OpenTYCwin;
    typedef void (FAR PASCAL * READTYC)(TYCrec &lin, char *&SMnum, bool &ok);
    READTYC ReadTYC;
    typedef void (FAR PASCAL * NEXTTYC)( bool &ok);
    NEXTTYC NextTYC;
    typedef void (FAR PASCAL * CLOSETYC)();
    CLOSETYC  CloseTYC ;

    // Tycho-2 catalogue
    typedef void (FAR PASCAL * SETTY2PATH)(char *path);
    SETTY2PATH SetTY2path;
    typedef void (FAR PASCAL * OPENTY2)(double ar1, double ar2, double de1, double de2, long ncat, bool &ok);
    OPENTY2 OpenTY2;
    typedef void (FAR PASCAL * OPENTY2WIN)(long ncat, bool &ok);
    OPENTY2WIN OpenTY2win;
    typedef void (FAR PASCAL * READTY2)(TY2rec &lin, char *&SMnum, bool &ok);
    READTY2 ReadTY2;
    typedef void (FAR PASCAL * NEXTTY2)( bool &ok);
    NEXTTY2 NextTY2;
    typedef void (FAR PASCAL * CLOSETY2)();
    CLOSETY2  CloseTY2 ;

    // Tycho input catalogue
    typedef void (FAR PASCAL * SETTICPATH)(char *path);
    SETTICPATH SetTICpath;
    typedef void (FAR PASCAL * OPENTIC)(double ar1, double ar2, double de1, double de2, bool &ok);
    OPENTIC OpenTIC;
    typedef void (FAR PASCAL * OPENTICWIN)(bool &ok);
    OPENTICWIN OpenTICwin;
    typedef void (FAR PASCAL * READTIC)(TICrec &lin, char *&SMnum, bool &ok);
    READTIC ReadTIC;
    typedef void (FAR PASCAL * NEXTTIC)( bool &ok);
    NEXTTIC NextTIC;
    typedef void (FAR PASCAL * CLOSETIC)();
    CLOSETIC  CloseTIC ;

    // Guide Star catalog (version produite par convgsc.exe)  XXX
    typedef void (FAR PASCAL * SETGSCPATH)(char *path);
    SETGSCPATH SetGSCpath;
    typedef void (FAR PASCAL * OPENGSC)(double ar1, double ar2, double de1, double de2, bool &ok);
    OPENGSC OpenGSC;
    typedef void (FAR PASCAL * OPENGSCWIN)(bool &ok);
    OPENGSCWIN OpenGSCwin;
    typedef void (FAR PASCAL * READGSC)(GSCrec &lin, char *&SMnum, bool &ok);
    READGSC ReadGSC;
    typedef void (FAR PASCAL * NEXTGSC)( bool &ok);
    NEXTGSC NextGSC;
    typedef void (FAR PASCAL * CLOSEGSC)();
    CLOSEGSC  CloseGSC ;

    // Guide Star catalog (Original version FITS)
    typedef void (FAR PASCAL * SETGSCFPATH)(char *path);
    SETGSCFPATH SetGSCFpath;
    typedef void (FAR PASCAL * OPENGSCF)(double ar1, double ar2, double de1, double de2, bool &ok);
    OPENGSCF OpenGSCF;
    typedef void (FAR PASCAL * OPENGSCFWIN)(bool &ok);
    OPENGSCFWIN OpenGSCFwin;
    typedef void (FAR PASCAL * READGSCF)(GSCFrec &lin, char *&SMnum, bool &ok);
    READGSCF ReadGSCF;
    typedef void (FAR PASCAL * CLOSEGSCF)();
    CLOSEGSCF  CloseGSCF ;

    // Guide Star catalog (Compact version of CDS)
    typedef void (FAR PASCAL * SETGSCCPATH)(char *path);
    SETGSCCPATH SetGSCCpath;
    typedef void (FAR PASCAL * OPENGSCC)(double ar1, double ar2, double de1, double de2, bool &ok);
    OPENGSCC OpenGSCC;
    typedef void (FAR PASCAL * OPENGSCCWIN)(bool &ok);
    OPENGSCCWIN OpenGSCCwin;
    typedef void (FAR PASCAL * READGSCC)(GSCCrec &lin, char *&SMnum, bool &ok);
    READGSCC ReadGSCC;
    typedef void (FAR PASCAL * NEXTGSCC)( bool &ok);
    NEXTGSCC NextGSCC;
    typedef void (FAR PASCAL * CLOSEGSCC)();
    CLOSEGSCC  CloseGSCC ;

    // US Naval Observatory USNO-A1,SA1,A2,SA2 catalog
    typedef void (FAR PASCAL * SETUSNOAPATH)(char *path);
    SETUSNOAPATH SetUSNOApath;
    typedef void (FAR PASCAL * OPENUSNOAWIN)(bool &ok);
    OPENUSNOAWIN OpenUSNOAwin;
    typedef void (FAR PASCAL * OPENUSNOA)(double ar1, double ar2, double de1, double de2, bool &ok);
    OPENUSNOA OpenUSNOA;
    typedef void (FAR PASCAL * READUSNOA)(USNOArec &lin, bool &ok);
    READUSNOA ReadUSNOA;
    typedef void (FAR PASCAL * CLOSEUSNOA)();
    CLOSEUSNOA  CloseUSNOA ;

    // MicroCat
    typedef void (FAR PASCAL * SETMCTPATH)(char *path);
    SETMCTPATH SetMCTpath;
    /* Suplemental paramater for open in microcat :
      ncat=1 : catalog Tycho
      ncat=2 : catalog Tycho + GSC
      ncat=3 : catalog Tycho + GSC + USNO */
    typedef void (FAR PASCAL * OPENMCTWIN)(long ncat, bool &ok);
    OPENMCTWIN OpenMCTwin;
    typedef void (FAR PASCAL * OPENMCT)(double ar1, double ar2, double de1, double de2, long ncat, bool &ok);
    OPENMCT OpenMCT;
    typedef void (FAR PASCAL * READMCT)(MCTrec &lin, bool &ok);
    READMCT ReadMCT;
    typedef void (FAR PASCAL * CLOSEMCT)();
    CLOSEMCT  CloseMCT ;

    // SAGUARO ASTRONOMY CLUB DATABASE  V7
    typedef void (FAR PASCAL * SETSACPATH)(char *path);
    SETSACPATH SetSACpath;
    typedef void (FAR PASCAL * OPENSAC)(double ar1, double ar2, double de1, double de2, bool &ok);
    OPENSAC OpenSAC;
    typedef void (FAR PASCAL * OPENSACWIN)(bool &ok);
    OPENSACWIN OpenSACwin;
    typedef void (FAR PASCAL * READSAC)(SACrec &lin, bool &ok);
    READSAC ReadSAC;
    typedef void (FAR PASCAL * CLOSESAC)();
    CLOSESAC  CloseSAC ;

    // NGC 2000
    typedef void (FAR PASCAL * SETNGCPATH)(char *path);
    SETNGCPATH SetNGCpath;
    typedef void (FAR PASCAL * OPENNGC)(double ar1, double ar2, double de1, double de2, bool &ok);
    OPENNGC OpenNGC;
    typedef void (FAR PASCAL * OPENNGCWIN)(bool &ok);
    OPENNGCWIN OpenNGCwin;
    typedef void (FAR PASCAL * READNGC)(NGCrec &lin, bool &ok);
    READNGC ReadNGC;
    typedef void (FAR PASCAL * CLOSENGC)();
    CLOSENGC  CloseNGC ;

    // Lynds' Catalogue of Bright Nebulae
    typedef void (FAR PASCAL * SETLBNPATH)(char *path);
    SETLBNPATH SetLBNpath;
    typedef void (FAR PASCAL * OPENLBN)(double ar1, double ar2, double de1, double de2, bool &ok);
    OPENLBN OpenLBN;
    typedef void (FAR PASCAL * OPENLBNWIN)(bool &ok);
    OPENLBNWIN OpenLBNwin;
    typedef void (FAR PASCAL * READLBN)(LBNrec &lin, bool &ok);
    READLBN ReadLBN;
    typedef void (FAR PASCAL * CLOSELBN)();
    CLOSELBN  CloseLBN ;

    // Third Reference Cat. of Bright Galaxies (RC3)
    typedef void (FAR PASCAL * SETRC3PATH)(char *path);
    SETRC3PATH SetRC3path;
    typedef void (FAR PASCAL * OPENRC3)(double ar1, double ar2, double de1, double de2, bool &ok);
    OPENRC3 OpenRC3;
    typedef void (FAR PASCAL * OPENRC3WIN)(bool &ok);
    OPENRC3WIN OpenRC3win;
    typedef void (FAR PASCAL * READRC3)(RC3rec &lin, bool &ok);
    READRC3 ReadRC3;
    typedef void (FAR PASCAL * CLOSERC3)();
    CLOSERC3  CloseRC3 ;

    // Catalogue of Principal Galaxies (PGC)
    typedef void (FAR PASCAL * SETPGCPATH)(char *path);
    SETPGCPATH SetPGCpath;
    typedef void (FAR PASCAL * OPENPGC)(double ar1, double ar2, double de1, double de2, bool &ok);
    OPENPGC OpenPGC;
    typedef void (FAR PASCAL * OPENPGCWIN)(bool &ok);
    OPENPGCWIN OpenPGCwin;
    typedef void (FAR PASCAL * READPGC)(PGCrec &lin, bool &ok);
    READPGC ReadPGC;
    typedef void (FAR PASCAL * CLOSEPGC)();
    CLOSEPGC  ClosePGC ;

    // Open Cluster Data
    typedef void (FAR PASCAL * SETOCLPATH)(char *path);
    SETOCLPATH SetOCLpath;
    typedef void (FAR PASCAL * OPENOCL)(double ar1, double ar2, double de1, double de2, bool &ok);
    OPENOCL OpenOCL;
    typedef void (FAR PASCAL * OPENOCLWIN)(bool &ok);
    OPENOCLWIN OpenOCLwin;
    typedef void (FAR PASCAL * READOCL)(OCLrec &lin, bool &ok);
    READOCL ReadOCL;
    typedef void (FAR PASCAL * CLOSEOCL)();
    CLOSEOCL  CloseOCL ;

    // Globular Clusters in the Milky Way
    typedef void (FAR PASCAL * SETGCMPATH)(char *path);
    SETGCMPATH SetGCMpath;
    typedef void (FAR PASCAL * OPENGCM)(double ar1, double ar2, double de1, double de2, bool &ok);
    OPENGCM OpenGCM;
    typedef void (FAR PASCAL * OPENGCMWIN)(bool &ok);
    OPENGCMWIN OpenGCMwin;
    typedef void (FAR PASCAL * READGCM)(GCMrec &lin, bool &ok);
    READGCM ReadGCM;
    typedef void (FAR PASCAL * CLOSEGCM)();
    CLOSEGCM  CloseGCM ;

    // Strasbourg-ESO Catalogue of Galactic Planetary Nebulae
    typedef void (FAR PASCAL * SETGPNPATH)(char *path);
    SETGPNPATH SetGPNpath;
    typedef void (FAR PASCAL * OPENGPN)(double ar1, double ar2, double de1, double de2, bool &ok);
    OPENGPN OpenGPN;
    typedef void (FAR PASCAL * OPENGPNWIN)(bool &ok);
    OPENGPNWIN OpenGPNwin;
    typedef void (FAR PASCAL * READGPN)(GPNrec &lin, bool &ok);
    READGPN ReadGPN;
    typedef void (FAR PASCAL * CLOSEGPN)();
    CLOSEGPN  CloseGPN ;

    // Washington Visual Double Star Catalog
    typedef void (FAR PASCAL * SETWDSPATH)(char *path);
    SETWDSPATH SetWDSpath;
    typedef void (FAR PASCAL * OPENWDS)(double ar1, double ar2, double de1, double de2, bool &ok);
    OPENWDS OpenWDS;
    typedef void (FAR PASCAL * OPENWDSWIN)(bool &ok);
    OPENWDSWIN OpenWDSwin;
    typedef void (FAR PASCAL * READWDS)(WDSrec &lin, bool &ok);
    READWDS ReadWDS;
    typedef void (FAR PASCAL * NEXTWDS)( bool &ok);
    NEXTWDS NextWDS;
    typedef void (FAR PASCAL * CLOSEWDS)();
    CLOSEWDS  CloseWDS ;

    // General Catalog of Variable Stars (+NSV +EVS)
    typedef void (FAR PASCAL * SETGCVPATH)(char *path);
    SETGCVPATH SetGCVpath;
    typedef void (FAR PASCAL * OPENGCV)(double ar1, double ar2, double de1, double de2, bool &ok);
    OPENGCV OpenGCV;
    typedef void (FAR PASCAL * OPENGCVWIN)(bool &ok);
    OPENGCVWIN OpenGCVwin;
    typedef void (FAR PASCAL * READGCV)(GCVrec &lin, bool &ok);
    READGCV ReadGCV;
    typedef void (FAR PASCAL * NEXTGCV)( bool &ok);
    NEXTGCV NextGCV;
    typedef void (FAR PASCAL * CLOSEGCV)();
    CLOSEGCV  CloseGCV ;

    // Recherche de la position d'un objet ( ne pas oublier d'appeller la SetPathXXX corespondante)
    typedef void (FAR PASCAL * FINDNUMNGC)(long id, double &ar, double &de, bool &ok);
    FINDNUMNGC FindNumNGC;
    typedef void (FAR PASCAL * FINDNUMIC)(long id, double &ar, double &de, bool &ok);
    FINDNUMIC FindNumIC;
    typedef void (FAR PASCAL * FINDNUMMESSIER)(long id, double &ar, double &de, bool &ok);
    FINDNUMMESSIER FindNumMessier;
    typedef void (FAR PASCAL * FINDNUMGCVS)(char *id, double &ar, double &de, bool &ok);
    FINDNUMGCVS FindNumGCVS;
    typedef void (FAR PASCAL * FINDNUMGSC)(char *id, double &ar, double &de, bool &ok);
    FINDNUMGSC FindNumGSC;
    typedef void (FAR PASCAL * FINDNUMGSCF)(char *id, double &ar, double &de, bool &ok);
    FINDNUMGSCF FindNumGSCF;
    typedef void (FAR PASCAL * FINDNUMGSCC)(char *id, double &ar, double &de, bool &ok);
    FINDNUMGSCC FindNumGSCC;
    typedef void (FAR PASCAL * FINDNUMGC)(long id, double &ar, double &de, bool &ok);
    FINDNUMGC FindNumGC;
    typedef void (FAR PASCAL * FINDNUMHR)(long id, double &ar, double &de, bool &ok);
    FINDNUMHR FindNumHR;
    typedef void (FAR PASCAL * FINDNUMBAYER)(char *id, double &ar, double &de, bool &ok);
    FINDNUMBAYER FindNumBayer;
    typedef void (FAR PASCAL * FINDNUMFLAM)(char *id, double &ar, double &de, bool &ok);
    FINDNUMFLAM FindNumFlam;
    typedef void (FAR PASCAL * FINDNUMHD)(long id, double &ar, double &de, bool &ok);
    FINDNUMHD FindNumHD;
    typedef void (FAR PASCAL * FINDNUMSAO)(long id, double &ar, double &de, bool &ok);
    FINDNUMSAO FindNumSAO;
    typedef void (FAR PASCAL * FINDNUMBD)(char *id, double &ar, double &de, bool &ok);
    FINDNUMBD FindNumBD;
    typedef void (FAR PASCAL * FINDNUMCD)(char *id, double &ar, double &de, bool &ok);
    FINDNUMCD FindNumCD;
    typedef void (FAR PASCAL * FINDNUMCPD)(char *id, double &ar, double &de, bool &ok);
    FINDNUMCPD FindNumCPD;
    typedef void (FAR PASCAL * FINDNUMPGC)(long id, double &ar, double &de, bool &ok);
    FINDNUMPGC FindNumPGC;
    typedef void (FAR PASCAL * FINDNUMSAC)(char *id, double &ar, double &de, bool &ok);
    FINDNUMSAC FindNumSAC;
};

///////////////////////////////////////////////////////////////////////////////
#endif // !defined(AFX_CCDCDATABASE_H__7A95BE14_EB96_499E_AEB3_4E70F9247974__INCLUDED_)
